@@ -205,10 +205,18 @@ class Frame(DialogsMixin,dialogs.BrowseMixin,droplet.Mixin,paint.Mixin,
         self._title()
         self._description()
         self._drop()
+        self._set_size()
         self._events()
         self._pubsub()
         if actionlist.endswith(ct.EXTENSION):
             self._open(actionlist)
+            
+    def _set_size(self):
+        #make it eee pc friendly
+        self._width       = 400
+        self._max_height  = wx.Display(0).GetGeometry().GetHeight()-50
+        self.SetSize((self._width,min(600,self._max_height)))
+        super(Frame,self).__set_properties()
         
     def _plugin(self):
         plugin.install_frame(self)
@@ -397,7 +405,8 @@ class Frame(DialogsMixin,dialogs.BrowseMixin,droplet.Mixin,paint.Mixin,
         self._open(filename)
         
     def on_menu_edit_add(self, event): 
-        dlg = dialogs.ActionDialog(self,api.ACTIONS,-1,size=(400, 400),
+        dlg = dialogs.ActionDialog(self,api.ACTIONS,-1,
+            size=(self._width, min(400,self._max_height)),
             title="%(name)s "%ct.INFO+_("actions"), )
         if dlg.ShowModal() == wx.ID_OK:
             self.set_dirty(True)
@@ -449,7 +458,7 @@ class Frame(DialogsMixin,dialogs.BrowseMixin,droplet.Mixin,paint.Mixin,
         
     def on_menu_tools_image_inspector(self, event):
         frame   = imageInspector.SingleFrame(self,
-            size    = imageInspector.SIZE,
+            size    = (470,min(510,self._max_height)),
             icon    = self.icon)
         frame.Show()
         
@@ -697,7 +706,7 @@ class Frame(DialogsMixin,dialogs.BrowseMixin,droplet.Mixin,paint.Mixin,
         if folder is None:
             return
         try:
-            create_phatch_droplet(self.filename,folder)
+            method(folder=folder,*args)
             self.show_info(_('Phatch successfully created the droplet.'))
         except Exception, details:
             reason  = exception_to_unicode(details,WX_ENCODING)
